package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class ResponseBytes extends ASN1Encodable {
   DERObjectIdentifier responseType;
   ASN1OctetString response;

   public ResponseBytes(DERObjectIdentifier responseType, ASN1OctetString response) {
      this.responseType = responseType;
      this.response = response;
   }

   public ResponseBytes(ASN1Sequence seq) {
      this.responseType = (DERObjectIdentifier)seq.getObjectAt(0);
      this.response = (ASN1OctetString)seq.getObjectAt(1);
   }

   public static ResponseBytes getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static ResponseBytes getInstance(Object obj) {
      if (obj != null && !(obj instanceof ResponseBytes)) {
         if (obj instanceof ASN1Sequence) {
            return new ResponseBytes((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (ResponseBytes)obj;
      }
   }

   public DERObjectIdentifier getResponseType() {
      return this.responseType;
   }

   public ASN1OctetString getResponse() {
      return this.response;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.responseType);
      var10000.add(this.response);
      return new DERSequence(var1);
   }
}
